GetDisjointMutError

Enum GetDisjointMutError 

1.86.0 ยท Source
pub enum GetDisjointMutError {
    IndexOutOfBounds,
    OverlappingIndices,
}
The error type returned by get_disjoint_mut.

It indicates one of two possible errors:

  • An index is out-of-bounds.
  • The same index appeared multiple times in the array (or different but overlapping indices when ranges are provided).

Examples

use std::slice::GetDisjointMutError;

let v = &mut [1, 2, 3];
assert_eq!(v.get_disjoint_mut([0, 999]), Err(GetDisjointMutError::IndexOutOfBounds));
assert_eq!(v.get_disjoint_mut([1, 1]), Err(GetDisjointMutError::OverlappingIndices));

Variants

1.86.0

IndexOutOfBounds

An index provided was out-of-bounds for the slice.

1.86.0

OverlappingIndices

Two indices provided were overlapping.