SplitInclusive

Struct SplitInclusive 

1.51.0 · Source
pub struct SplitInclusive<'a, T: 'a, P>
where P: FnMut(&T) -> bool,
{ /* private fields */ }
An iterator over subslices separated by elements that match a predicate function. Unlike Split, it contains the matched part as a terminator of the subslice.

This struct is created by the split_inclusive method on slices.

Example

let slice = [10, 40, 33, 20];
let mut iter = slice.split_inclusive(|num| num % 3 == 0);
assert_eq!(iter.next(), Some(&[10, 40, 33][..]));
assert_eq!(iter.next(), Some(&[20][..]));
assert_eq!(iter.next(), None);